==> nextcloud-26.0.7p0.tgz: nextcloud/apps/systemtags/l10n/hu.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "A címke neve üres",
    "Update" : "Frissítés",
    "Create" : "Létrehozás",
    "Select tag …" : "Válasszon címkét…",
    "System tag %1$s added by the system" : "A rendszer hozzáadta a(z) %1$s rendszercímkét",
    "Added system tag {systemtag}" : "{systemtag} rendszercímke hozzáadva",
    "Added system tag %1$s" : "%1$s rendszercímke hozzáadva",
    "%1$s added system tag %2$s" : "%1$s hozzáadta a(z) %2$s rendszercímkét",
    "{actor} added system tag {systemtag}" : "{actor} hozzáadta a(z) {systemtag} rendszercímkét",
    "System tag %1$s removed by the system" : "A rendszer eltávolította a(z) %1$s rendszercímkét",
    "Removed system tag {systemtag}" : "{systemtag} rendszercímke eltávolítva",
    "Removed system tag %1$s" : "%1$s rendszercímke eltávolítva",
    "%1$s removed system tag %2$s" : "%1$s eltávolította a(z) %2$s rendszercímkét",
    "{actor} removed system tag {systemtag}" : "{actor} eltávolította a(z) {systemtag} rendszercímkét",
    "You created system tag %1$s" : "Létrehozta a(z) %1$s rendszercímkét",
    "You created system tag {systemtag}" : "Létrehozta a(z) {systemtag} rendszercímkét",
    "%1$s created system tag %2$s" : "%1$s létrehozta ezt a rendszer címkét: %2$s",
    "{actor} created system tag {systemtag}" : "{actor} létrehozta a(z) {systemtag} rendszercímkét",
    "You deleted system tag %1$s" : "Törölte a(z) %1$s rendszercímkét",
    "You deleted system tag {systemtag}" : "Törölte a(z) {systemtag} rendszercímkét",
    "%1$s deleted system tag %2$s" : "%1$s törölte a(z) %2$s rendszercímkét",
    "{actor} deleted system tag {systemtag}" : "{actor} törölte a(z) {systemtag} rendszercímkét",
    "You updated system tag %2$s to %1$s" : "Frissítette a(z) %2$s rendszercímkét a következőre: %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Frissítette a(z) {oldsystemtag} rendszercímkét a következőre: {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s erre frissítette a(z) %3$s rendszercímkét: %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} erre frissítette a(z) {oldsystemtag} rendszercímkét: {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "A rendszer hozzáadta a(z) %2$s rendszercímkét a(z) %1$s fájlhoz",
    "System tag {systemtag} was added to {file} by the system" : "A rendszer hozzáadta a(z) {systemtag} rendszercímkét a(z) {file} fájlhoz",
    "You added system tag %2$s to %1$s" : "Hozzáadta a(z) %2$s rendszercímkét a(z) %1$s fájlhoz",
    "You added system tag {systemtag} to {file}" : "Hozzáadta a(z) {systemtag} rendszercímkét a(z) {file} fájlhoz",
    "%1$s added system tag %3$s to %2$s" : "%1$s hozzáadta a(z) %3$s rendszercímkét a(z) %2$s fájlhoz",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hozzáadta a(z) {systemtag} rendszercímkét a(z) {file} fájlhoz",
    "System tag %2$s was removed from %1$s by the system" : "A rendszer eltávolította a(z) %2$s rendszercímkét a(z) %1$s fájlról",
    "System tag {systemtag} was removed from {file} by the system" : "A rendszer eltávolította a(z) {systemtag} rendszercímkét a(z) {file} fájlról",
    "You removed system tag %2$s from %1$s" : "Eltávolította a(z) %2$s rendszercímkét a(z) %1$s fájlról",
    "You removed system tag {systemtag} from {file}" : "Eltávolította a(z) {systemtag} rendszercímkét a(z) {file} fájlról",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eltávolította a(z) %3$s rendszercímkét a(z) %2$s fájlról",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eltávolította a(z) {systemtag} rendszercímkét a(z) {file} fájlról",
    "%s (restricted)" : "%s (korlátozott)",
    "%s (invisible)" : "%s (láthatatlan)",
    "<strong>System tags</strong> for a file have been modified" : "A fájl <strong>rendszercímkéi</strong> módosítva lettek",
    "Tags" : "Címkék",
    "All tagged %s …" : "Összes ezzel címkézett: %s…",
    "tagged %s" : "ezzel címkézett: %s",
    "Collaborative tags" : "Együttműködési címkék",
    "Collaborative tagging functionality which shares tags among users." : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között. Nagyszerű a csapatok számára.\n\t(Ha Ön több szervezet számára szolgáltatást nyújtó szolgáltató, akkor ajánlott deaktiválni ezt az alkalmazást, mivel a címkék meg vannak osztva.)",
    "Loading collaborative tags …" : "Együttműködési címkék betöltése…",
    "Search or create collaborative tags" : "Együttműködési címkék keresése és létrehozása",
    "Collaborative tags …" : "Együttműködési címkék…",
    "No tags to select, type to create a new tag" : "Nincs kiválasztható címke, gépeljen egy új címke létrehozásához",
    "Failed to load tags" : "A címkék betöltése sikertelen",
    "Failed to load selected tags" : "A kiválasztott címkék betöltése sikertelen",
    "Failed to select tag" : "A címke kiválasztása sikertelen",
    "Failed to create tag" : "A címke létrehozása sikertelen",
    "Failed to delete tag" : "A címke törlése sikertelen",
    "This file has the tag {tag}" : "Ennek a fájlnak ez a címkéje: {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Ennek a fájlnak ezek a címkéi: {firstTags} és {lastTag}",
    "No tags found" : "Nem találhatók címkék",
    "Failed to load last used tags" : "A legutóbb használt címkék betöltése sikertelen",
    "Missing \"Content-Location\" header" : "Hiányzó „Content-Location” fejléc",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Az együttműködési címkék elérhetők az összes felhasználó számára. A korlátozott címkék láthatók a felhasználók által, de nem rendelhetik azt semmihez. A láthatatlan címkék belső használatra vannak fenntartva, mivel a felhasználók nem látják ezeket, és nem is tudják semmihez hozzárendelni őket.",
    "Create a new tag" : "Új címke létrehozása",
    "Name" : "Név",
    "Public" : "Nyilvános",
    "Restricted" : "Korlátozott",
    "Invisible" : "Láthatatlan",
    "Delete" : "Törlés",
    "Reset" : "Visszaállítás",
    "No files in here" : "Itt nincsenek fájlok",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "Tagged files" : "Címkézett fájlok",
    "Select tags to filter by" : "Válasszon címkéket a szűréshez:",
    "Please select tags to filter by" : "Válasszon címkéket a szűréshez:",
    "No files found for the selected tags" : "Nem található fájl a kiválasztott címkéhez"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.5.tgz: nextcloud/apps/systemtags/l10n/hu.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "A rendszer hozzáadta a(z) %1$s rendszercímkét",
    "Added system tag {systemtag}" : "{systemtag} rendszercímke hozzáadva",
    "Added system tag %1$s" : "%1$s rendszercímke hozzáadva",
    "%1$s added system tag %2$s" : "%1$s hozzáadta a(z) %2$s rendszercímkét",
    "{actor} added system tag {systemtag}" : "{actor} hozzáadta a(z) {systemtag} rendszercímkét",
    "System tag %1$s removed by the system" : "A rendszer eltávolította a(z) %1$s rendszercímkét",
    "Removed system tag {systemtag}" : "{systemtag} rendszercímke eltávolítva",
    "Removed system tag %1$s" : "%1$s rendszercímke eltávolítva",
    "%1$s removed system tag %2$s" : "%1$s eltávolította a(z) %2$s rendszercímkét",
    "{actor} removed system tag {systemtag}" : "{actor} eltávolította a(z) {systemtag} rendszercímkét",
    "You created system tag %1$s" : "Létrehozta a(z) %1$s rendszercímkét",
    "You created system tag {systemtag}" : "Létrehozta a(z) {systemtag} rendszercímkét",
    "%1$s created system tag %2$s" : "%1$s létrehozta ezt a rendszer címkét: %2$s",
    "{actor} created system tag {systemtag}" : "{actor} létrehozta a(z) {systemtag} rendszercímkét",
    "You deleted system tag %1$s" : "Törölte a(z) %1$s rendszercímkét",
    "You deleted system tag {systemtag}" : "Törölte a(z) {systemtag} rendszercímkét",
    "%1$s deleted system tag %2$s" : "%1$s törölte a(z) %2$s rendszercímkét",
    "{actor} deleted system tag {systemtag}" : "{actor} törölte a(z) {systemtag} rendszercímkét",
    "You updated system tag %2$s to %1$s" : "Frissítette a(z) %2$s rendszercímkét a következőre: %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Frissítette a(z) {oldsystemtag} rendszercímkét a következőre: {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s erre frissítette a(z) %3$s rendszercímkét: %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} erre frissítette a(z) {oldsystemtag} rendszercímkét: {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "A rendszer hozzáadta a(z) %2$s rendszercímkét a(z) %1$s fájlhoz",
    "System tag {systemtag} was added to {file} by the system" : "A rendszer hozzáadta a(z) {systemtag} rendszercímkét a(z) {file} fájlhoz",
    "You added system tag %2$s to %1$s" : "Hozzáadta a(z) %2$s rendszercímkét a(z) %1$s fájlhoz",
    "You added system tag {systemtag} to {file}" : "Hozzáadta a(z) {systemtag} rendszercímkét a(z) {file} fájlhoz",
    "%1$s added system tag %3$s to %2$s" : "%1$s hozzáadta a(z) %3$s rendszercímkét a(z) %2$s fájlhoz",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hozzáadta a(z) {systemtag} rendszercímkét a(z) {file} fájlhoz",
    "System tag %2$s was removed from %1$s by the system" : "A rendszer eltávolította a(z) %2$s rendszercímkét a(z) %1$s fájlról",
    "System tag {systemtag} was removed from {file} by the system" : "A rendszer eltávolította a(z) {systemtag} rendszercímkét a(z) {file} fájlról",
    "You removed system tag %2$s from %1$s" : "Eltávolította a(z) %2$s rendszercímkét a(z) %1$s fájlról",
    "You removed system tag {systemtag} from {file}" : "Eltávolította a(z) {systemtag} rendszercímkét a(z) {file} fájlról",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eltávolította a(z) %3$s rendszercímkét a(z) %2$s fájlról",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eltávolította a(z) {systemtag} rendszercímkét a(z) {file} fájlról",
    "%s (restricted)" : "%s (korlátozott)",
    "%s (invisible)" : "%s (láthatatlan)",
    "<strong>System tags</strong> for a file have been modified" : "A fájl <strong>rendszercímkéi</strong> módosítva lettek",
    "Tags" : "Címkék",
    "All tagged %s …" : "Összes ezzel címkézett: %s…",
    "tagged %s" : "ezzel címkézett: %s",
    "Collaborative tags" : "Együttműködési címkék",
    "Collaborative tagging functionality which shares tags among users." : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között. Nagyszerű a csapatok számára.\n\t(Ha Ön több szervezet számára szolgáltatást nyújtó szolgáltató, akkor ajánlott deaktiválni ezt az alkalmazást, mivel a címkék meg vannak osztva.)",
    "Collaborative tags …" : "Együttműködési címkék…",
    "Tag name" : "Címke név",
    "Tag level" : "Címke szint",
    "Create" : "Létrehozás",
    "Update" : "Frissítés",
    "Delete" : "Törlés",
    "Reset" : "Visszaállítás",
    "Loading …" : "Betöltés…",
    "Public" : "Nyilvános",
    "Restricted" : "Korlátozott",
    "Invisible" : "Láthatatlan",
    "Failed to create tag" : "A címke létrehozása sikertelen",
    "Failed to delete tag" : "A címke törlése sikertelen",
    "Loading collaborative tags …" : "Együttműködési címkék betöltése…",
    "Search or create collaborative tags" : "Együttműködési címkék keresése és létrehozása",
    "No tags to select, type to create a new tag" : "Nincs kiválasztható címke, gépeljen egy új címke létrehozásához",
    "Failed to load tags" : "A címkék betöltése sikertelen",
    "Failed to load selected tags" : "A kiválasztott címkék betöltése sikertelen",
    "Failed to select tag" : "A címke kiválasztása sikertelen",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Az együttműködési címkék elérhetők az összes felhasználó számára. A korlátozott címkék láthatók a felhasználók által, de nem rendelhetik azt semmihez. A láthatatlan címkék belső használatra vannak fenntartva, mivel a felhasználók nem látják ezeket, és nem is tudják semmihez hozzárendelni őket.",
    "This file has the tag {tag}" : "Ennek a fájlnak ez a címkéje: {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Ennek a fájlnak ezek a címkéi: {firstTags} és {lastTag}",
    "List of tags and their associated files and folders." : "A címkék és a hozzájuk tartozó fájlok és mappák listázása.",
    "No tags found" : "Nem találhatók címkék",
    "Tags you have created will show up here." : "A saját címkék itt jelennek meg.",
    "Failed to load last used tags" : "A legutóbb használt címkék betöltése sikertelen",
    "Missing \"Content-Location\" header" : "Hiányzó „Content-Location” fejléc",
    "No files in here" : "Itt nincsenek fájlok",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "Tag name is empty" : "A címke neve üres",
    "Select tag …" : "Válasszon címkét…",
    "Tagged files" : "Címkézett fájlok",
    "Select tags to filter by" : "Válasszon címkéket a szűréshez:",
    "Please select tags to filter by" : "Válasszon címkéket a szűréshez:",
    "No files found for the selected tags" : "Nem található fájl a kiválasztott címkéhez",
    "Create a new tag" : "Új címke létrehozása"
},
"nplurals=2; plural=(n != 1);");
